@@ -296,7 +296,16 @@ eog_util_dot_dir (void)
 		
 		exists = ensure_dir_exists (dot_dir);
 
-		g_assert (exists);
+		if (G_UNLIKELY (!exists)) {
+			static gboolean printed_warning = FALSE;
+
+			if (!printed_warning) {
+				g_warning ("EOG could not save some of your preferences in its settings directory due to a file with the same name (%s) blocking its creation. Please remove that file, or move it away.", dot_dir);
+				printed_warning = TRUE;
+			}
+			dot_dir = NULL;
+			return NULL;
+		}
 	}
 
 	return dot_dir;
